Class: Helios::Seo::LlmsController

Inherits:
ApplicationController show all
Defined in:
app/controllers/helios/seo/llms_controller.rb

Overview

Serves /llms.txt — a markdown site summary plus a list of published posts with canonical URLs, generated from the resource the host configures via config.llms_posts.

Instance Method Summary collapse

Instance Method Details

#showObject



7
8
9
10
11
12
13
14
15
# File 'app/controllers/helios/seo/llms_controller.rb', line 7

def show
  @config  = Helios::Seo.configuration
  @entries = posts.map do |post|
    presenter = ResourcePresenter.new(post, @config)
    { title: presenter.name, url: presenter.canonical_url }
  end

  render layout: false, content_type: "text/plain"
end